/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03401
 |         SUBSTANCE ABUSE TREATMENT COST ALLOCATION AND ANALYSIS
 |                  TEMPLATE (SATCAAT) STUDY, 1992-1994
 |       (DATASET 0001: RESIDENTIAL WOMEN AND CHILDREN SDU SUMMARY)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03401-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE caseid    -9='(-9) BLANK' ;
  VALUE sdunum    -9='(-9) BLANK' ;
  VALUE sdutype   -9='(-9) BLANK' 1='(1) RES. PREGNANT & POSTPARTUM WOMEN-SDU SUMMARY'
                  2='(2) RES. LONG TERM PPW-SDU SUMMARY'
                  3='(3) RES. SHORT TERM PPW-SDU SUMMARY'
                  4='(4) RES. WOMEN & CHILDREN-SDU SUMMARY' ;
  VALUE provider  -9='(-9) BLANK' ;
  VALUE numclnt   -9='(-9) BLANK' ;
  VALUE fyend     -9='(-9) BLANK' ;
  VALUE totcost   -9='(-9) BLANK' ;
  VALUE totaft    -9='(-9) BLANK' ;
  VALUE totcnet   -9='(-9) BLANK' ;
  VALUE totch     -9='(-9) BLANK' ;
  VALUE totcled   -9='(-9) BLANK' ;
  VALUE tottran   -9='(-9) BLANK' ;
  VALUE tothiv    -9='(-9) BLANK' ;
  VALUE tothous   -9='(-9) BLANK' ;
  VALUE tothm     -9='(-9) BLANK' ;
  VALUE totiass   -9='(-9) BLANK' ;
  VALUE totmds    -9='(-9) BLANK' ;
  VALUE totmes    -9='(-9) BLANK' ;
  VALUE totmhgc   -9='(-9) BLANK' ;
  VALUE totmhic   -9='(-9) BLANK' ;
  VALUE totpevl   -9='(-9) BLANK' ;
  VALUE totpse    -9='(-9) BLANK' ;
  VALUE totrmgt   -9='(-9) BLANK' ;
  VALUE totsted   -9='(-9) BLANK' ;
  VALUE totsagc   -9='(-9) BLANK' ;
  VALUE totsaic   -9='(-9) BLANK' ;
  VALUE cstprcl   -9.00='(-9.00) BLANK' ;
  VALUE avgaft    -9.00='(-9.00) BLANK' ;
  VALUE avgcnet   -9.00='(-9.00) BLANK' ;
  VALUE avgch     -9.00='(-9.00) BLANK' ;
  VALUE avgcled   -9.00='(-9.00) BLANK' ;
  VALUE avgtran   -9.00='(-9.00) BLANK' ;
  VALUE avghiv    -9.00='(-9.00) BLANK' ;
  VALUE avghous   -9.00='(-9.00) BLANK' ;
  VALUE avghm     -9.00='(-9.00) BLANK' ;
  VALUE avgiass   -9.00='(-9.00) BLANK' ;
  VALUE avgmds    -9.00='(-9.00) BLANK' ;
  VALUE avgmes    -9.00='(-9.00) BLANK' ;
  VALUE avgmhgc   -9.00='(-9.00) BLANK' ;
  VALUE avgmhic   -9.00='(-9.00) BLANK' ;
  VALUE avgpevl   -9.00='(-9.00) BLANK' ;
  VALUE avgpse    -9.00='(-9.00) BLANK' ;
  VALUE avgrmgt   -9.00='(-9.00) BLANK' ;
  VALUE avgsagc   -9.00='(-9.00) BLANK' ;
  VALUE avgsaic   -9.00='(-9.00) BLANK' ;
  VALUE avgsted   -9.00='(-9.00) BLANK' ;
  VALUE unaft7ff  -9='(-9) BLANK' ;
  VALUE unaft9ff  -9='(-9) BLANK' ;
  VALUE unaft10f  -9='(-9) BLANK' ;
  VALUE unaft12f  -9='(-9) BLANK' ;
  VALUE unaft3ff  -9='(-9) BLANK' ;
  VALUE uncnet7f  -9='(-9) BLANK' ;
  VALUE uncnet9f  -9='(-9) BLANK' ;
  VALUE uncnet1f  -9='(-9) BLANK' ;
  VALUE uncnet0f  -9='(-9) BLANK' ;
  VALUE uncnet2f  -9='(-9) BLANK' ;
  VALUE uncnet3f  -9='(-9) BLANK' ;
  VALUE unch5fff  -9='(-9) BLANK' ;
  VALUE uncled7f  -9='(-9) BLANK' ;
  VALUE untran7f  -9='(-9) BLANK' ;
  VALUE untran1f  -9='(-9) BLANK' ;
  VALUE untran3f  -9='(-9) BLANK' ;
  VALUE untran0f  -9='(-9) BLANK' ;
  VALUE unhiv7ff  -9='(-9) BLANK' ;
  VALUE unhiv23f  -9='(-9) BLANK' ;
  VALUE unhous1f  -9='(-9) BLANK' ;
  VALUE unhm18ff  -9='(-9) BLANK' ;
  VALUE uniass3f  -9='(-9) BLANK' ;
  VALUE uniass2f  -9='(-9) BLANK' ;
  VALUE unmds7ff  -9='(-9) BLANK' ;
  VALUE unmds25f  -9='(-9) BLANK' ;
  VALUE unmds31f  -9='(-9) BLANK' ;
  VALUE unmds3ff  -9='(-9) BLANK' ;
  VALUE unmds24f  -9='(-9) BLANK' ;
  VALUE unmes15f  -9='(-9) BLANK' ;
  VALUE unmes16f  -9='(-9) BLANK' ;
  VALUE unmes31f  -9='(-9) BLANK' ;
  VALUE unmhgc3f  -9='(-9) BLANK' ;
  VALUE unmhgc1f  -9='(-9) BLANK' ;
  VALUE unmhic1f  -9='(-9) BLANK' ;
  VALUE unmhic8f  -9='(-9) BLANK' ;
  VALUE unpev7ff  -9='(-9) BLANK' ;
  VALUE unpse13f  -9='(-9) BLANK' ;
  VALUE unpse14f  -9='(-9) BLANK' ;
  VALUE unpse16f  -9='(-9) BLANK' ;
  VALUE unpse31f  -9='(-9) BLANK' ;
  VALUE unrmgt7f  -9='(-9) BLANK' ;
  VALUE unrmgt3f  -9='(-9) BLANK' ;
  VALUE unrmgt4f  -9='(-9) BLANK' ;
  VALUE unrmgt2f  -9='(-9) BLANK' ;
  VALUE unsted7f  -9='(-9) BLANK' ;
  VALUE unsted1f  -9='(-9) BLANK' ;
  VALUE unsted3f  -9='(-9) BLANK' ;
  VALUE unsagc1f  -9='(-9) BLANK' ;
  VALUE unsagc3f  -9='(-9) BLANK' ;
  VALUE unsaic1f  -9='(-9) BLANK' ;
  VALUE unsai31f  -9='(-9) BLANK' ;
  VALUE ucaft7ff  -9.00='(-9.00) BLANK' ;
  VALUE ucstaftf  -9.00='(-9.00) BLANK' ;
  VALUE ucaft10f  -9.00='(-9.00) BLANK' ;
  VALUE ucaft12f  -9.00='(-9.00) BLANK' ;
  VALUE ucaft3ff  -9.00='(-9.00) BLANK' ;
  VALUE uccnet7f  -9.00='(-9.00) BLANK' ;
  VALUE uccnet9f  -9.00='(-9.00) BLANK' ;
  VALUE uccnet1f  -9.00='(-9.00) BLANK' ;
  VALUE uccnet0f  -9.00='(-9.00) BLANK' ;
  VALUE uccnet2f  -9.00='(-9.00) BLANK' ;
  VALUE uccnet3f  -9.00='(-9.00) BLANK' ;
  VALUE ucch5fff  -9.00='(-9.00) BLANK' ;
  VALUE uccled7f  -9.00='(-9.00) BLANK' ;
  VALUE uctran7f  -9.00='(-9.00) BLANK' ;
  VALUE uctran1f  -9.00='(-9.00) BLANK' ;
  VALUE uctran3f  -9.00='(-9.00) BLANK' ;
  VALUE uctran0f  -9.00='(-9.00) BLANK' ;
  VALUE uchiv7ff  -9.00='(-9.00) BLANK' ;
  VALUE uchiv23f  -9.0='(-9.0) BLANK' ;
  VALUE uchous1f  -9.00='(-9.00) BLANK' ;
  VALUE uchm18ff  -9.00='(-9.00) BLANK' ;
  VALUE ucmhic1f  -9.00='(-9.00) BLANK' ;
  VALUE uciass3f  -9.00='(-9.00) BLANK' ;
  VALUE uciass2f  -9.00='(-9.00) BLANK' ;
  VALUE ucmds7ff  -9.00='(-9.00) BLANK' ;
  VALUE ucmds25f  -9.00='(-9.00) BLANK' ;
  VALUE ucmds31f  -9.00='(-9.00) BLANK' ;
  VALUE ucmds3ff  -9.00='(-9.00) BLANK' ;
  VALUE ucmds24f  -9.00='(-9.00) BLANK' ;
  VALUE ucmes15f  -9.00='(-9.00) BLANK' ;
  VALUE ucmes16f  -9.00='(-9.00) BLANK' ;
  VALUE ucmes31f  -9.00='(-9.00) BLANK' ;
  VALUE ucmhgc1f  -9.00='(-9.00) BLANK' ;
  VALUE ucpev7ff  -9.00='(-9.00) BLANK' ;
  VALUE ucpse13f  -9.00='(-9.00) BLANK' ;
  VALUE ucpse14f  -9.00='(-9.00) BLANK' ;
  VALUE ucpse16f  -9.00='(-9.00) BLANK' ;
  VALUE ucpse31f  -9.00='(-9.00) BLANK' ;
  VALUE ucrmgt7f  -9.00='(-9.00) BLANK' ;
  VALUE ucrmgt3f  -9.00='(-9.00) BLANK' ;
  VALUE ucrmgt4f  -9.00='(-9.00) BLANK' ;
  VALUE ucrmgt2f  -9.00='(-9.00) BLANK' ;
  VALUE ucsted7f  -9.00='(-9.00) BLANK' ;
  VALUE ucsted1f  -9.00='(-9.00) BLANK' ;
  VALUE ucsted3f  -9.00='(-9.00) BLANK' ;
  VALUE ucsagc1f  -9.00='(-9.00) BLANK' ;
  VALUE ucsagc3f  -9.00='(-9.00) BLANK' ;
  VALUE ucsaic1f  -9.00='(-9.00) BLANK' ;
  VALUE ucsaic3f  -9='(-9) BLANK' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=726;
INPUT
        CASEID 1-2              SDUNUM 3-4              SDUTYPE 5
        PROVIDER 6-7            NUMCLNT 8-10            FYEND 11-14
        TOTCOST 15-21           TOTAFT 22-26            TOTCNET 27-32
        TOTCH 33-38             TOTCLED 39-43           TOTTRAN 44-49
        TOTHIV 50-54            TOTHOUS 55-60           TOTHM 61-66
        TOTIASS 67-71           TOTMDS 72-77            TOTMES 78-82
        TOTMHGC 83-87           TOTMHIC 88-92           TOTPEVL 93-98
        TOTPSE 99-103           TOTRMGT 104-109         TOTSTED 110-114
        TOTSAGC 115-120         TOTSAIC 121-126         CSTPRCL 127-134 .2
        AVGAFT 135-141 .2       AVGCNET 142-148 .2      AVGCH 149-156 .2
        AVGCLED 157-163 .2      AVGTRAN 164-170 .2      AVGHIV 171-176 .2
        AVGHOUS 177-184 .2      AVGHM 185-192 .2        AVGIASS 193-199 .2
        AVGMDS 200-206 .2       AVGMES 207-212 .2       AVGMHGC 213-218 .2
        AVGMHIC 219-225 .2      AVGPEVL 226-232 .2      AVGPSE 233-239 .2
        AVGRMGT 240-247 .2      AVGSAGC 248-254 .2      AVGSAIC 255-261 .2
        AVGSTED 262-268 .2      UNAFT7 269-270          UNAFT9 271-274
        UNAFT10 275-278         UNAFT12 279-280         UNAFT3 281-283
        UNCNET7 284-285         UNCNET9 286-289         UNCNET10 290-294
        UNCNET16 295-297        UNCNET20 298-300        UNCNET31 301-302
        UNCH5 303-305           UNCLED7 306-308         UNTRAN7 309-311
        UNTRAN16 312-314        UNTRAN31 315-316        UNTRAN32 317-320
        UNHIV7 321-323          UNHIV23 324-325         UNHOUS18 326-330
        UNHM18 331-335          UNIASS31 336-337        UNIASS2 338-340
        UNMDS7 341-344          UNMDS25 345-347         UNMDS31 348-349
        UNMDS3 350-352          UNMDS24 353-356         UNMES15 357-359
        UNMES16 360-361         UNMES31 362-363         UNMHGC31 364-365
        UNMHGC11 366-368        UNMHIC11 369-372        UNMHIC8 373-374
        UNPEV7 375-377          UNPSE13 378-380         UNPSE14 381-383
        UNPSE16 384-386         UNPSE31 387-388         UNRMGT7 389-390
        UNRMGT31 391-392        UNRMGT4 393-395         UNRMGT24 396-398
        UNSTED7 399-401         UNSTED16 402-404        UNSTED31 405-406
        UNSAGC11 407-410        UNSAGC31 411-414        UNSAIC11 415-419
        UNSAI31 420-424         UCAFT7 425-430 .2       UCSTAFT9 431-436 .2
        UCAFT10 437-442 .2      UCAFT12 443-448 .2      UCAFT3 449-455 .2
        UCCNET7 456-462 .2      UCCNET9 463-467 .2      UCCNET10 468-474 .2
        UCCNET16 475-480 .2     UCCNET20 481-487 .2     UCCNET31 488-493 .2
        UCCH5 494-501 .2        UCCLED7 502-508 .2      UCTRAN7 509-515 .2
        UCTRAN16 516-521 .2     UCTRAN31 522-528 .2     UCTRAN32 529-535 .2
        UCHIV7 536-541 .2       UCHIV23 542-546 .1      UCHOUS18 547-552 .2
        UCHM18 553-558 .2       UCMHIC11 559-564 .2     UCIASS31 565-569 .2
        UCIASS2 570-576 .2      UCMDS7 577-583 .2       UCMDS25 584-588 .2
        UCMDS31 589-594 .2      UCMDS3 595-601 .2       UCMDS24 602-607 .2
        UCMES15 608-613 .2      UCMES16 614-619 .2      UCMES31 620-624 .2
        UCMHGC11 625-629 .2     UCPEV7 630-636 .2       UCPSE13 637-642 .2
        UCPSE14 643-649 .2      UCPSE16 650-655 .2      UCPSE31 656-661 .2
        UCRMGT7 662-668 .2      UCRMGT31 669-675 .2     UCRMGT4 676-682 .2
        UCRMGT24 683-689 .2     UCSTED7 690-696 .2      UCSTED16 697-702 .2
        UCSTED31 703-708 .2     UCSAGC11 709-714 .2     UCSAGC31 715-719 .2
        UCSAIC11 720-724 .2     UCSAIC31 725-726        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   SDUNUM  = 'SERVICE DELIVERY UNIT IDENTIFICATION NUMBER'
   SDUTYPE = 'SERVICE DELIVERY UNIT TYPE'
   PROVIDER= 'PROVIDER IDENTIFICATION NUMBER'
   NUMCLNT = 'DERIVED NUMBER OF WOMEN CLIENTS IN SDU'
   FYEND   = 'FISCAL YEAR ENDING'
   TOTCOST = 'TOTAL SDU COST'
   TOTAFT  = 'AFTERCARE SVC-TOTAL SDU COST'
   TOTCNET = 'CASE MGT/NETWRK SVC-TOTAL SDU COST'
   TOTCH   = 'CHILD CARE SVC-TOTAL SDU COST'
   TOTCLED = 'CLIENT EDUC SVC-TOTAL SDU COST'
   TOTTRAN = 'CLIENT TRANSPORT SVC-TOTAL SDU COST'
   TOTHIV  = 'HIV TEST & COUNSEL SVC-TOTAL SDU COST'
   TOTHOUS = 'HOUSING SVC-TOTAL SDU COST'
   TOTHM   = 'HOUSING & MEAL SVC-TOTAL SDU COST'
   TOTIASS = 'INITIAL ASSESSMENT SVC-TOTAL SDU COST'
   TOTMDS  = 'MED & DIAG SVC-TOTAL SDU COST'
   TOTMES  = 'MEDICAL EXAM SVC-TOTAL SDU COST'
   TOTMHGC = 'MH GROUP COUNSEL SVC-TOTAL SDU COST'
   TOTMHIC = 'MH INDIV COUNSEL SVC-TOTAL SDU COST'
   TOTPEVL = 'PROJECT EVAL SVC-TOTAL SDU COST'
   TOTPSE  = 'PSYCHOSOCIAL EVAL SVC-TOTAL SDU COST'
   TOTRMGT = 'RECORDS MGT SVC-TOTAL SDU COST'
   TOTSTED = 'STAFF EDUC SVC-TOTAL SDU COST'
   TOTSAGC = 'SA GROUP COUNSEL SVC-TOTAL SDU COST'
   TOTSAIC = 'SA INDIV COUNSEL SVC-TOTAL SDU COST'
   CSTPRCL = 'OVERALL SDU COST PER CLIENT'
   AVGAFT  = 'AFTERCARE SVC-AVG COST PER CLIENT'
   AVGCNET = 'CASE MGT/NETWRK SVC-AVG COST PER CLIENT'
   AVGCH   = 'CHILD CARE SVC-AVG COST PER CLIENT'
   AVGCLED = 'CLIENT EDUC SVC-AVG COST PER CLIENT'
   AVGTRAN = 'CLIENT TRANSPORT SVC-AVG COST PER CLIENT'
   AVGHIV  = 'HIV TEST & COUNSEL SVC-AVG COST PER CLIENT'
   AVGHOUS = 'HOUSING SVC-AVG COST PER CLIENT'
   AVGHM   = 'HOUSING & MEAL SVC-AVG COST PER CLIENT'
   AVGIASS = 'INITIAL ASSESSMENT SVC-AVG COST PER CLIENT'
   AVGMDS  = 'MED & DIAG SVC-AVG COST PER CLIENT'
   AVGMES  = 'MEDICAL EXAM SVC-AVG COST PER CLIENT'
   AVGMHGC = 'MH GROUP COUNSEL SVC-AVG COST PER CLIENT'
   AVGMHIC = 'MH INDIV COUNSEL SVC-AVG COST PER CLIENT'
   AVGPEVL = 'PROJECT EVAL SVC-AVG COST PER CLIENT'
   AVGPSE  = 'PSYCHOSOCIAL EVAL SVC-AVG COST PER CLIENT'
   AVGRMGT = 'RECORDS MGT SVC-AVG COST PER CLIENT'
   AVGSAGC = 'SA GROUP COUNSEL SVC-AVG COST PER CLIENT'
   AVGSAIC = 'SA INDIV COUNSEL SVC-AVG COST PER CLIENT'
   AVGSTED = 'STAFF EDUC SVC-AVG COST PER CLIENT'
   UNAFT7  = 'AFTERCARE SVC-TOTAL CLIENTS REC THIS SVC'
   UNAFT9  = 'AFTERCARE SVC-TOTAL CONTACT HOURS'
   UNAFT10 = 'AFTERCARE SVC-TOTAL CONTACTS'
   UNAFT12 = 'AFTERCARE SVC-TOTAL DISCHARGES'
   UNAFT3  = 'AFTERCARE SVC-TOTAL CASES'
   UNCNET7 = 'CASE MGT/NETWRK SVC-TOTAL CLIENTS REC THIS SVC'
   UNCNET9 = 'CASE MGT/NETWRK SVC-TOTAL CONTACT HOURS'
   UNCNET10= 'CASE MGT/NETWRK SVC-TOTAL CONTACTS'
   UNCNET16= 'CASE MGT/NETWRK SVC-TOTAL HOURS'
   UNCNET20= 'CASE MGT/NETWRK SVC-TOTAL NETWORKING CASES'
   UNCNET31= 'CASE MGT/NETWRK SVC-TOTAL UNSPECIFIED UNITS'
   UNCH5   = 'CHILD CARE SVC-TOTAL CHILDREN'
   UNCLED7 = 'CLIENT EDUC SVC-TOTAL CLIENTS REC THIS SVC'
   UNTRAN7 = 'CLIENT TRANSPORT SVC-TOTAL CLIENTS REC THIS SVC'
   UNTRAN16= 'CLIENT TRANSPORT SVC-TOTAL HOURS'
   UNTRAN31= 'CLIENT TRANSPORT SVC-TOTAL UNSPECIFIED UNITS'
   UNTRAN32= 'CLIENT TRANSPORT SVC-TOTAL CLIENT TRIPS'
   UNHIV7  = 'HIV TEST & COUNSEL SVC-TOTAL CLIENTS REC THIS SVC'
   UNHIV23 = 'HIV TEST & COUNSEL SVC-TOTAL RISK ASSESSMENTS'
   UNHOUS18= 'HOUSING SVC-TOTAL INPATIENT DAYS'
   UNHM18  = 'HOUSING & MEAL SVC-TOTAL INPATIENT DAYS'
   UNIASS31= 'INITIAL ASSESSMENT SVC-TOTAL UNSPECIFIED UNITS'
   UNIASS2 = 'INITIAL ASSESSMENT SVC-TOTAL ASSESSMENTS'
   UNMDS7  = 'MED & DIAG SVC-TOTAL CLIENTS REC THIS SVC'
   UNMDS25 = 'MED & DIAG SVC-TOTAL SERVICE HOURS'
   UNMDS31 = 'MED & DIAG SVC-TOTAL UNSPECIFIED UNITS'
   UNMDS3  = 'MED & DIAG SVC-TOTAL CASES'
   UNMDS24 = 'MED & DIAG SVC-TOTAL SERVICES'
   UNMES15 = 'MEDICAL EXAM SVC-TOTAL EXAMS'
   UNMES16 = 'MEDICAL EXAM SVC-TOTAL HOURS'
   UNMES31 = 'MEDICAL EXAM SVC-TOTAL UNSPECIFIED UNITS'
   UNMHGC31= 'MH GROUP COUNSELING SVC-TOTAL UNSPECIFIED UNITS'
   UNMHGC11= 'MH GROUP COUNSELING SVC-TOTAL COUNSELING HOURS'
   UNMHIC11= 'MH INDIV COUNSEL-TOTAL COUNSELING HOURS'
   UNMHIC8 = 'MH INDIV COUNSEL-TOTAL CONSULTING HOURS'
   UNPEV7  = 'PROJECT EVALUATION SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNPSE13 = 'PSYCHOSOCIAL EVAL SVC-TOTAL EVALUATION HOURS'
   UNPSE14 = 'PSYCHOSOCIAL EVAL SVC-TOTAL EVALUATIONS'
   UNPSE16 = 'PSYCHOSOCIAL EVAL SVC-TOTAL HOURS'
   UNPSE31 = 'PSYCHOSOCIAL EVAL SVC-TOTAL UNSPECIFIED UNITS'
   UNRMGT7 = 'RECORDS MGT SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNRMGT31= 'RECORDS MGT SVC-TOTAL UNSPECIFIED UNITS'
   UNRMGT4 = 'RECORDS MGT SVC-TOTAL CASES'
   UNRMGT24= 'RECORDS MGT SVC-TOTAL SERVICES'
   UNSTED7 = 'STAFF EDUCATION SVC-TOTAL UNITS (W/CLIENTS AS UNITS)'
   UNSTED16= 'STAFF EDUCATION SVC-TOTAL HOURS'
   UNSTED31= 'STAFF EDUCATION SVC-TOTAL UNSPECIFIED UNITS'
   UNSAGC11= 'SA GROUP COUNSELING SVC-TOTAL COUNSELING HOURS'
   UNSAGC31= 'SA GROUP COUNSELING SVC-TOTAL UNSPECIFIED UNITS'
   UNSAIC11= 'SA INDIV COUNSEL SVC-TOTAL COUNSELING HOURS'
   UNSAI31 = 'SA INDIV COUNSEL SVC-TOTAL UNSPECIFIED UNITS'
   UCAFT7  = 'AFTERCARE SVC-COST PER CLIENT REC THIS SVC'
   UCSTAFT9= 'AFTERCARE SVC-COST PER CONTACT HOUR'
   UCAFT10 = 'AFTERCARE SVC-COST PER CONTACT'
   UCAFT12 = 'AFTERCARE SVC-COST PER DISCHARGE'
   UCAFT3  = 'AFTERCARE SVC-COST PER CASE'
   UCCNET7 = 'CASE MGT/NETWRK SVC-COST PER CLIENT REC THIS SVC'
   UCCNET9 = 'CASE MGT/NETWRK SVC-COST PER CONTACT HOUR'
   UCCNET10= 'CASE MGT/NETWRK SVC-COST PER CONTACT'
   UCCNET16= 'CASE MGT/NETWRK SVC-COST PER HOUR'
   UCCNET20= 'CASE MGT/NETWRK SVC-COST PER NETWORKING CASE'
   UCCNET31= 'CASE MGT/NETWRK SVC-PRORATED COST PER UNSPEC UNIT'
   UCCH5   = 'CHILD CARE SVC-COST PER CHILD'
   UCCLED7 = 'CLIENT EDUC-COST PER CLIENT REC THIS SVC'
   UCTRAN7 = 'CLIENT TRANSPORT SVC-COST PER CLIENT REC THIS SVC'
   UCTRAN16= 'CLIENT TRANSPORT SVC-COST PER HOUR'
   UCTRAN31= 'CLIENT TRANSPORT SVC-PRORATED COST PER UNSPEC UNIT'
   UCTRAN32= 'CLIENT TRANSPORT SVC-COST PER CLIENT TRIP'
   UCHIV7  = 'HIV TEST & COUNSEL-COST PER CLIENT REC THIS SVC'
   UCHIV23 = 'HIV TEST & COUNSEL-COST PER RISK ASSESSMT'
   UCHOUS18= 'HOUSING SVC-COST PER INPATIENT DAY'
   UCHM18  = 'HOUSING & MEAL SVC-COST PER INPATIENT DAY'
   UCMHIC11= 'MH INDIV COUNSEL SVC-COST PER COUNSELING HR'
   UCIASS31= 'INITIAL ASSESSMENT SVC-PRORATED COST PER UNSPEC UNIT'
   UCIASS2 = 'INITIAL ASSESSMENT SVC-COST PER ASSESSMENT'
   UCMDS7  = 'MED & DIAG SVC-COST PER CLIENT REC THIS SVC'
   UCMDS25 = 'MED & DIAG SVC-COST PER SERVICE HOUR'
   UCMDS31 = 'MED & DIAG SVC-PRORATED COST PER UNSPEC UNIT'
   UCMDS3  = 'MED & DIAG SVC-COST PER CASE'
   UCMDS24 = 'MED & DIAG SVC-COST PER SERVICE'
   UCMES15 = 'MEDICAL EXAM SVC-COST PER EXAM'
   UCMES16 = 'MEDICAL EXAM SVC-COST PER HOUR'
   UCMES31 = 'MEDICAL EXAM SVC-PRORATED COST PER UNSPEC UNIT'
   UCMHGC11= 'MH GROUP COUNSELING SVC-COST PER COUNSELING HR'
   UCPEV7  = 'PROJECT EVALUATION SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCPSE13 = 'PSYCHOSOCIAL EVAL SVC-COST PER EVALUATION HOUR'
   UCPSE14 = 'PSYCHOSOCIAL EVAL SVC-COST PER EVALUATION'
   UCPSE16 = 'PSYCHOSOCIAL EVAL SVC-COST PER HOUR'
   UCPSE31 = 'PSYCHOSOCIAL EVAL SVC-PRORATED COST PER UNSPEC UNIT'
   UCRMGT7 = 'RECORDS MGT SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCRMGT31= 'RECORDS MGT SVC-PRORATED COST PER UNSPEC UNIT'
   UCRMGT4 = 'RECORDS MGT SVC-COST PER CASE'
   UCRMGT24= 'RECORDS MGT SVC-COST PER SERVICE'
   UCSTED7 = 'STAFF EDUC SVC-COST PER UNIT (W/CLIENTS AS UNITS)'
   UCSTED16= 'STAFF EDUC SVC-COST PER HOUR'
   UCSTED31= 'STAFF EDUC SVC-PRORATED COST PER UNSPEC UNIT'
   UCSAGC11= 'SA GROUP COUNSELING SVC-COST PER COUNSELING HR'
   UCSAGC31= 'SA GROUP COUNSELING SVC-PRORATED COST PER UNSPEC UNIT'
   UCSAIC11= 'SA INDIV COUNSEL-COST PER COUNSELING HR'
   UCSAIC31= 'SA INDIV COUNSEL-PRORATED COST PER UNSPEC UNIT'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (SDUTYPE <= -1) THEN SDUTYPE = .;
   IF (NUMCLNT <= -1) THEN NUMCLNT = .;
   IF (FYEND <= -1) THEN FYEND = .;
   IF (TOTCOST <= -1) THEN TOTCOST = .;
   IF (TOTAFT <= -1) THEN TOTAFT = .;
   IF (TOTCNET <= -1) THEN TOTCNET = .;
   IF (TOTCH <= -1) THEN TOTCH = .;
   IF (TOTCLED <= -1) THEN TOTCLED = .;
   IF (TOTTRAN <= -1) THEN TOTTRAN = .;
   IF (TOTHIV <= -1) THEN TOTHIV = .;
   IF (TOTHOUS <= -1) THEN TOTHOUS = .;
   IF (TOTHM <= -1) THEN TOTHM = .;
   IF (TOTIASS <= -1) THEN TOTIASS = .;
   IF (TOTMDS <= -1) THEN TOTMDS = .;
   IF (TOTMES <= -1) THEN TOTMES = .;
   IF (TOTMHGC <= -1) THEN TOTMHGC = .;
   IF (TOTMHIC <= -1) THEN TOTMHIC = .;
   IF (TOTPEVL <= -1) THEN TOTPEVL = .;
   IF (TOTPSE <= -1) THEN TOTPSE = .;
   IF (TOTRMGT <= -1) THEN TOTRMGT = .;
   IF (TOTSTED <= -1) THEN TOTSTED = .;
   IF (TOTSAGC <= -1) THEN TOTSAGC = .;
   IF (TOTSAIC <= -1) THEN TOTSAIC = .;
   IF (CSTPRCL <= -1.00) THEN CSTPRCL = .;
   IF (AVGAFT <= -1.00) THEN AVGAFT = .;
   IF (AVGCNET <= -1.00) THEN AVGCNET = .;
   IF (AVGCH <= -1.00) THEN AVGCH = .;
   IF (AVGCLED <= -1.00) THEN AVGCLED = .;
   IF (AVGTRAN <= -1.00) THEN AVGTRAN = .;
   IF (AVGHIV <= -1.00) THEN AVGHIV = .;
   IF (AVGHOUS <= -1.00) THEN AVGHOUS = .;
   IF (AVGHM <= -1.00) THEN AVGHM = .;
   IF (AVGIASS <= -1.00) THEN AVGIASS = .;
   IF (AVGMDS <= -1.00) THEN AVGMDS = .;
   IF (AVGMES <= -1.00) THEN AVGMES = .;
   IF (AVGMHGC <= -1.00) THEN AVGMHGC = .;
   IF (AVGMHIC <= -1.00) THEN AVGMHIC = .;
   IF (AVGPEVL <= -1.00) THEN AVGPEVL = .;
   IF (AVGPSE <= -1.00) THEN AVGPSE = .;
   IF (AVGRMGT <= -1.00) THEN AVGRMGT = .;
   IF (AVGSAGC <= -1.00) THEN AVGSAGC = .;
   IF (AVGSAIC <= -1.00) THEN AVGSAIC = .;
   IF (AVGSTED <= -1.00) THEN AVGSTED = .;
   IF (UNAFT7 <= -1) THEN UNAFT7 = .;
   IF (UNAFT9 <= -1) THEN UNAFT9 = .;
   IF (UNAFT10 <= -1) THEN UNAFT10 = .;
   IF (UNAFT12 <= -1) THEN UNAFT12 = .;
   IF (UNAFT3 <= -1) THEN UNAFT3 = .;
   IF (UNCNET7 <= -1) THEN UNCNET7 = .;
   IF (UNCNET9 <= -1) THEN UNCNET9 = .;
   IF (UNCNET10 <= -1) THEN UNCNET10 = .;
   IF (UNCNET16 <= -1) THEN UNCNET16 = .;
   IF (UNCNET20 <= -1) THEN UNCNET20 = .;
   IF (UNCNET31 <= -1) THEN UNCNET31 = .;
   IF (UNCH5 <= -1) THEN UNCH5 = .;
   IF (UNCLED7 <= -1) THEN UNCLED7 = .;
   IF (UNTRAN7 <= -1) THEN UNTRAN7 = .;
   IF (UNTRAN16 <= -1) THEN UNTRAN16 = .;
   IF (UNTRAN31 <= -1) THEN UNTRAN31 = .;
   IF (UNTRAN32 <= -1) THEN UNTRAN32 = .;
   IF (UNHIV7 <= -1) THEN UNHIV7 = .;
   IF (UNHIV23 <= -1) THEN UNHIV23 = .;
   IF (UNHOUS18 <= -1) THEN UNHOUS18 = .;
   IF (UNHM18 <= -1) THEN UNHM18 = .;
   IF (UNIASS31 <= -1) THEN UNIASS31 = .;
   IF (UNIASS2 <= -1) THEN UNIASS2 = .;
   IF (UNMDS7 <= -1) THEN UNMDS7 = .;
   IF (UNMDS25 <= -1) THEN UNMDS25 = .;
   IF (UNMDS31 <= -1) THEN UNMDS31 = .;
   IF (UNMDS3 <= -1) THEN UNMDS3 = .;
   IF (UNMDS24 <= -1) THEN UNMDS24 = .;
   IF (UNMES15 <= -1) THEN UNMES15 = .;
   IF (UNMES16 <= -1) THEN UNMES16 = .;
   IF (UNMES31 <= -1) THEN UNMES31 = .;
   IF (UNMHGC31 <= -1) THEN UNMHGC31 = .;
   IF (UNMHGC11 <= -1) THEN UNMHGC11 = .;
   IF (UNMHIC11 <= -1) THEN UNMHIC11 = .;
   IF (UNMHIC8 <= -1) THEN UNMHIC8 = .;
   IF (UNPEV7 <= -1) THEN UNPEV7 = .;
   IF (UNPSE13 <= -1) THEN UNPSE13 = .;
   IF (UNPSE14 <= -1) THEN UNPSE14 = .;
   IF (UNPSE16 <= -1) THEN UNPSE16 = .;
   IF (UNPSE31 <= -1) THEN UNPSE31 = .;
   IF (UNRMGT7 <= -1) THEN UNRMGT7 = .;
   IF (UNRMGT31 <= -1) THEN UNRMGT31 = .;
   IF (UNRMGT4 <= -1) THEN UNRMGT4 = .;
   IF (UNRMGT24 <= -1) THEN UNRMGT24 = .;
   IF (UNSTED7 <= -1) THEN UNSTED7 = .;
   IF (UNSTED16 <= -1) THEN UNSTED16 = .;
   IF (UNSTED31 <= -1) THEN UNSTED31 = .;
   IF (UNSAGC11 <= -1) THEN UNSAGC11 = .;
   IF (UNSAGC31 <= -1) THEN UNSAGC31 = .;
   IF (UNSAIC11 <= -1) THEN UNSAIC11 = .;
   IF (UNSAI31 <= -1) THEN UNSAI31 = .;
   IF (UCAFT7 <= -1.00) THEN UCAFT7 = .;
   IF (UCSTAFT9 <= -1.00) THEN UCSTAFT9 = .;
   IF (UCAFT10 <= -1.00) THEN UCAFT10 = .;
   IF (UCAFT12 <= -1.00) THEN UCAFT12 = .;
   IF (UCAFT3 <= -1.00) THEN UCAFT3 = .;
   IF (UCCNET7 <= -1.00) THEN UCCNET7 = .;
   IF (UCCNET9 <= -1.00) THEN UCCNET9 = .;
   IF (UCCNET10 <= -1.00) THEN UCCNET10 = .;
   IF (UCCNET16 <= -1.00) THEN UCCNET16 = .;
   IF (UCCNET20 <= -1.00) THEN UCCNET20 = .;
   IF (UCCNET31 <= -1.00) THEN UCCNET31 = .;
   IF (UCCH5 <= -1.00) THEN UCCH5 = .;
   IF (UCCLED7 <= -1.00) THEN UCCLED7 = .;
   IF (UCTRAN7 <= -1.00) THEN UCTRAN7 = .;
   IF (UCTRAN16 <= -1.00) THEN UCTRAN16 = .;
   IF (UCTRAN31 <= -1.00) THEN UCTRAN31 = .;
   IF (UCTRAN32 <= -1.00) THEN UCTRAN32 = .;
   IF (UCHIV7 <= -1.00) THEN UCHIV7 = .;
   IF (UCHIV23 <= -1.0) THEN UCHIV23 = .;
   IF (UCHOUS18 <= -1.00) THEN UCHOUS18 = .;
   IF (UCHM18 <= -1.00) THEN UCHM18 = .;
   IF (UCMHIC11 <= -1.00) THEN UCMHIC11 = .;
   IF (UCIASS31 <= -1.00) THEN UCIASS31 = .;
   IF (UCIASS2 <= -1.00) THEN UCIASS2 = .;
   IF (UCMDS7 <= -1.00) THEN UCMDS7 = .;
   IF (UCMDS25 <= -1.00) THEN UCMDS25 = .;
   IF (UCMDS31 <= -1.00) THEN UCMDS31 = .;
   IF (UCMDS3 <= -1.00) THEN UCMDS3 = .;
   IF (UCMDS24 <= -1.00) THEN UCMDS24 = .;
   IF (UCMES15 <= -1.00) THEN UCMES15 = .;
   IF (UCMES16 <= -1.00) THEN UCMES16 = .;
   IF (UCMES31 <= -1.00) THEN UCMES31 = .;
   IF (UCMHGC11 <= -1.00) THEN UCMHGC11 = .;
   IF (UCPEV7 <= -1.00) THEN UCPEV7 = .;
   IF (UCPSE13 <= -1.00) THEN UCPSE13 = .;
   IF (UCPSE14 <= -1.00) THEN UCPSE14 = .;
   IF (UCPSE16 <= -1.00) THEN UCPSE16 = .;
   IF (UCPSE31 <= -1.00) THEN UCPSE31 = .;
   IF (UCRMGT7 <= -1.00) THEN UCRMGT7 = .;
   IF (UCRMGT31 <= -1.00) THEN UCRMGT31 = .;
   IF (UCRMGT4 <= -1.00) THEN UCRMGT4 = .;
   IF (UCRMGT24 <= -1.00) THEN UCRMGT24 = .;
   IF (UCSTED7 <= -1.00) THEN UCSTED7 = .;
   IF (UCSTED16 <= -1.00) THEN UCSTED16 = .;
   IF (UCSTED31 <= -1.00) THEN UCSTED31 = .;
   IF (UCSAGC11 <= -1.00) THEN UCSAGC11 = .;
   IF (UCSAGC31 <= -1.00) THEN UCSAGC31 = .;
   IF (UCSAIC11 <= -1.00) THEN UCSAIC11 = .;
   IF (UCSAIC31 <= -1) THEN UCSAIC31 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CASEID caseid. SDUNUM sdunum. SDUTYPE sdutype.
         PROVIDER provider. NUMCLNT numclnt. FYEND fyend.
         TOTCOST totcost. TOTAFT totaft. TOTCNET totcnet.
         TOTCH totch. TOTCLED totcled. TOTTRAN tottran.
         TOTHIV tothiv. TOTHOUS tothous. TOTHM tothm.
         TOTIASS totiass. TOTMDS totmds. TOTMES totmes.
         TOTMHGC totmhgc. TOTMHIC totmhic. TOTPEVL totpevl.
         TOTPSE totpse. TOTRMGT totrmgt. TOTSTED totsted.
         TOTSAGC totsagc. TOTSAIC totsaic. CSTPRCL cstprcl.
         AVGAFT avgaft. AVGCNET avgcnet. AVGCH avgch.
         AVGCLED avgcled. AVGTRAN avgtran. AVGHIV avghiv.
         AVGHOUS avghous. AVGHM avghm. AVGIASS avgiass.
         AVGMDS avgmds. AVGMES avgmes. AVGMHGC avgmhgc.
         AVGMHIC avgmhic. AVGPEVL avgpevl. AVGPSE avgpse.
         AVGRMGT avgrmgt. AVGSAGC avgsagc. AVGSAIC avgsaic.
         AVGSTED avgsted. UNAFT7 unaft7ff. UNAFT9 unaft9ff.
         UNAFT10 unaft10f. UNAFT12 unaft12f. UNAFT3 unaft3ff.
         UNCNET7 uncnet7f. UNCNET9 uncnet9f. UNCNET10 uncnet1f.
         UNCNET16 uncnet0f. UNCNET20 uncnet2f. UNCNET31 uncnet3f.
         UNCH5 unch5fff. UNCLED7 uncled7f. UNTRAN7 untran7f.
         UNTRAN16 untran1f. UNTRAN31 untran3f. UNTRAN32 untran0f.
         UNHIV7 unhiv7ff. UNHIV23 unhiv23f. UNHOUS18 unhous1f.
         UNHM18 unhm18ff. UNIASS31 uniass3f. UNIASS2 uniass2f.
         UNMDS7 unmds7ff. UNMDS25 unmds25f. UNMDS31 unmds31f.
         UNMDS3 unmds3ff. UNMDS24 unmds24f. UNMES15 unmes15f.
         UNMES16 unmes16f. UNMES31 unmes31f. UNMHGC31 unmhgc3f.
         UNMHGC11 unmhgc1f. UNMHIC11 unmhic1f. UNMHIC8 unmhic8f.
         UNPEV7 unpev7ff. UNPSE13 unpse13f. UNPSE14 unpse14f.
         UNPSE16 unpse16f. UNPSE31 unpse31f. UNRMGT7 unrmgt7f.
         UNRMGT31 unrmgt3f. UNRMGT4 unrmgt4f. UNRMGT24 unrmgt2f.
         UNSTED7 unsted7f. UNSTED16 unsted1f. UNSTED31 unsted3f.
         UNSAGC11 unsagc1f. UNSAGC31 unsagc3f. UNSAIC11 unsaic1f.
         UNSAI31 unsai31f. UCAFT7 ucaft7ff. UCSTAFT9 ucstaftf.
         UCAFT10 ucaft10f. UCAFT12 ucaft12f. UCAFT3 ucaft3ff.
         UCCNET7 uccnet7f. UCCNET9 uccnet9f. UCCNET10 uccnet1f.
         UCCNET16 uccnet0f. UCCNET20 uccnet2f. UCCNET31 uccnet3f.
         UCCH5 ucch5fff. UCCLED7 uccled7f. UCTRAN7 uctran7f.
         UCTRAN16 uctran1f. UCTRAN31 uctran3f. UCTRAN32 uctran0f.
         UCHIV7 uchiv7ff. UCHIV23 uchiv23f. UCHOUS18 uchous1f.
         UCHM18 uchm18ff. UCMHIC11 ucmhic1f. UCIASS31 uciass3f.
         UCIASS2 uciass2f. UCMDS7 ucmds7ff. UCMDS25 ucmds25f.
         UCMDS31 ucmds31f. UCMDS3 ucmds3ff. UCMDS24 ucmds24f.
         UCMES15 ucmes15f. UCMES16 ucmes16f. UCMES31 ucmes31f.
         UCMHGC11 ucmhgc1f. UCPEV7 ucpev7ff. UCPSE13 ucpse13f.
         UCPSE14 ucpse14f. UCPSE16 ucpse16f. UCPSE31 ucpse31f.
         UCRMGT7 ucrmgt7f. UCRMGT31 ucrmgt3f. UCRMGT4 ucrmgt4f.
         UCRMGT24 ucrmgt2f. UCSTED7 ucsted7f. UCSTED16 ucsted1f.
         UCSTED31 ucsted3f. UCSAGC11 ucsagc1f. UCSAGC31 ucsagc3f.
         UCSAIC11 ucsaic1f. UCSAIC31 ucsaic3f.  ;
*/

RUN ;
